(v0.10.8)=
### 0.10.8 {small}`2024-06-20`

#### Bug fixes

* Write out `64bit` indptr when appropriate for {func}`~anndata.experimental.concat_on_disk` {pr}`1493` {user}`ilan-gold`
* Support for Numpy 2 {pr}`1499` {user}`flying-sheep`
* Fix {func}`~anndata.io.sparse_dataset` docstring test on account of new {mod}`scipy` version {pr}`1514` {user}`ilan-gold`

#### Documentation

* Improved example for {func}`~anndata.io.sparse_dataset` {pr}`1468` {user}`ivirshup`
